package com.ruoyi.system.mapper.fgw;

import com.ruoyi.system.domain.fgw.FgwFj;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 发改委_附件Mapper接口
 * 
 * @author boman
 * @date 2023-03-22
 */
public interface FgwFjMapper 
{
    /**
     * 查询发改委_附件
     * 
     * @param id 发改委_附件主键
     * @return 发改委_附件
     */
    public FgwFj selectFgwFjById(Long id);

    public List<FgwFj> selectFgwFjByXmId(Long id);
    public List<FgwFj> selectFgwFjBySourceId(Long id);

    /**
     * 查询发改委_附件列表
     * 
     * @param fgwFj 发改委_附件
     * @return 发改委_附件集合
     */
    public List<FgwFj> selectFgwFjList(FgwFj fgwFj);

    /**
     * 新增发改委_附件
     * 
     * @param fgwFj 发改委_附件
     * @return 结果
     */
    public int insertFgwFj(FgwFj fgwFj);

    /**
     * 修改发改委_附件
     * 
     * @param fgwFj 发改委_附件
     * @return 结果
     */
    public int updateFgwFj(FgwFj fgwFj);

    /**
     * 删除发改委_附件
     * 
     * @param id 发改委_附件主键
     * @return 结果
     */
    public int deleteFgwFjById(Long id);

    public int deleteFgwFjByXmId(@Param("id") Long id, @Param("type")Long type);

    /**
     * 批量删除发改委_附件
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteFgwFjByIds(Long[] ids);
}
